@@ -20,7 +20,7 @@ from pulsectl.pulsectl import (
 	PulseEventMaskEnum, PulseLoopStop, PulseOperationFailed, PulseIndexError, PulseSinkInfo, PulseSourceInfo,
 	PulseCardInfo, PulseSinkInputInfo, PulseSourceOutputInfo, PulseClientInfo, PulseServerInfo, PulseModuleInfo,
 	is_list, PulseOperationInvalid, PulsePortInfo, PulseExtStreamRestoreInfo, PulseUpdateEnum, is_str,
-	assert_pulse_object, PulseDisconnected, unicode)
+	assert_pulse_object, PulseDisconnected, unicode, Enum)
 from pulsectl import _pulsectl as c
 
 
@@ -91,6 +91,13 @@ class PulseAsync(object):
 		self.event_callback = None
 		self.waiting_futures = set()
 
+		chan_names = dict()
+		for n in range(256):
+			name = c.pa.channel_position_to_string(n)
+			if name is None: break
+			chan_names[n] = name
+		self.channel_list_enum = Enum('channel_pos', chan_names)
+
 	def _ctx_init(self):
 		if self._ctx:
 			self.disconnect()
@@ -349,6 +356,8 @@ class PulseAsync(object):
 			try: c.pa.context_load_module(self._ctx, name, args, cb, None)
 			except c.pa.CallError as err: raise PulseOperationInvalid(err.args[-1])
 		index, = data
+		if index == c.PA_INVALID:
+			raise PulseError('Failed to load module: {} {}'.format(name, args))
 		return index
 
 	module_unload = _pulse_method_call(c.pa.context_unload_module, None)
